console.log("KartCommand widget initialization script loaded");
console.log("stl_vars:", stl_vars);

(function () {
  var e = window,
    t = document;

  function initWidget() {
    if (typeof stl_vars === "undefined" || !stl_vars.widget_enable) {
      console.log(
        "KartCommand widget is not enabled or configuration is missing"
      );
      return;
    }

    let chatManagerId = stl_vars.widget_chat_manager;
    if (!chatManagerId) {
      console.error("KartCommand: Chat Manager ID is missing");
      return;
    }

    // Ensure the domain doesn't start with 'http://' or 'https://'
    let domain = (stl_vars.stl_domain || "app.speedtolead.io").replace(
      /^(https?:\/\/)/,
      ""
    );

    let ccCookie = ("; " + document.cookie).split(
      "; __stl_remote_contact_" + chatManagerId + "="
    );
    let cnvCookie = ("; " + document.cookie).split(
      "; __stl_conversation_" + chatManagerId + "="
    );

    var script = t.createElement("script");
    script.type = "text/javascript";
    script.async = true;
    script.crossOrigin = "*";
    script.id = "stl_iframe_feature";
    script.src =
      "https://" +
      domain +
      "/embed/widget/frame/" +
      chatManagerId +
      "?v=2&" +
      (ccCookie.length === 2 ? "cc=" + ccCookie.pop().split(";").shift() : "") +
      (cnvCookie.length === 2
        ? "&cnv=" + cnvCookie.pop().split(";").shift()
        : "");

    script.onerror = function () {
      console.error("Failed to load KartCommand widget script");
    };

    var firstScript = t.getElementsByTagName("script")[0];
    firstScript.parentNode.insertBefore(script, firstScript);
  }

  e.addEventListener("message", function (event) {
    let wrapper = window.document.getElementById("stl_widget_iframe_wrapper");
    let iframe = window.document.getElementById("stl_widget_iframe");

    if (
      wrapper &&
      event.data.indexOf("{") == 0 &&
      event.data.lastIndexOf("}") == event.data.length - 1
    ) {
      let data = JSON.parse(event.data);
      let keys = Object.keys(data);

      if (keys.indexOf("set_cookie") > -1) {
        document.cookie = data.set_cookie.value;
      } else if (keys.indexOf("toggle") > -1) {
        if (data.toggle) {
          wrapper.classList.add("stl_widget_open");
          wrapper.classList.remove("stl_widget_closed");
          iframe.classList.add("stl_widget_open");
          iframe.classList.remove("stl_widget_closed");
        } else {
          wrapper.classList.add("stl_widget_closed");
          wrapper.classList.remove("stl_widget_open");
          iframe.classList.add("stl_widget_closed");
          iframe.classList.remove("stl_widget_open");
        }
      } else if (keys.indexOf("add_to_cart") > -1) {
        let cartData = data.add_to_cart;
        let config = stl_vars;
        if (typeof config === "undefined") {
          config = {};
        }
        let nonce = config.wp_nonce;
        let attributes = [];

        if (cartData.attributes) {
          cartData.attributes.forEach((attr) => {
            attributes.push({ attribute: attr.slug, value: attr.value });
          });
        }

        let postData = JSON.stringify({
          id: cartData.id,
          quantity: cartData.quantity,
          variation: attributes,
        });

        let xhr = new XMLHttpRequest();
        xhr.open("POST", "/wp-json/wc/store/cart/add-item", true);
        xhr.setRequestHeader("X-WC-Store-API-Nonce", nonce);
        xhr.setRequestHeader("Nonce", nonce);
        xhr.setRequestHeader("Content-type", "application/json; charset=UTF-8");
        xhr.send(postData);

        xhr.onload = function () {
          if (xhr.status === 201 || xhr.status === 200) {
            console.log("Item added to cart!");
            try {
              jQuery("[name='update_cart']").prop("disabled", false);
              jQuery("[name='update_cart']").trigger("click");
            } catch (error) {
              console.log("cart reload error: " + error);
            }
          }
        };
      }
    }
  });

  if (t.readyState !== "loading") {
    initWidget();
  } else {
    e.addEventListener("load", initWidget, false);
  }
})();
