<?php
class KartCommand_Admin
{
    public function __construct()
    {
        add_action('admin_menu', array($this, 'add_admin_menu'));
        add_action('admin_init', array($this, 'register_settings'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_admin_scripts'));
        add_action('updated_option', array($this, 'send_settings_to_kartcommand'), 10, 3);
    }

    public function enqueue_admin_scripts($hook)
    {
        wp_enqueue_style('kartcommand-admin', plugin_dir_url(__FILE__) . '../assets/css/kartcommand-admin.css', array(), KARTCOMMAND_VERSION);
        if ('toplevel_page_kartcommand' !== $hook) {
            return;
        }
        wp_enqueue_media();
        wp_enqueue_script('kartcommand-admin', plugin_dir_url(__FILE__) . '../assets/js/admin.js', array('jquery'), KARTCOMMAND_VERSION, true);
    }

    // Add this method to load Dashicons
    public function enqueue_admin_styles()
    {
        wp_enqueue_style('dashicons');
    }

    public function add_admin_menu()
    {
        add_menu_page(
            'KartCommand Settings',
            'KartCommand',
            'manage_options',
            'kartcommand',
            array($this, 'display_admin_page'),
            'dashicons-kartcommand', //'dashicons-cart',  // Use a different built-in Dashicon
            26 // Position
        );
    }

    public function maybe_update_plugin()
    {
        $current_version = get_option('kartcommand_version', '0');
        if (version_compare($current_version, '3.1.5', '<')) {
            // Perform any necessary updates
            update_option('kartcommand_version', '3.1.5');
        }
    }

    public function register_settings()
    {
        if (false === get_option('kartcommand_domain')) {
            update_option('kartcommand_domain', 'app.kartcommand.com');
        }

        $text_field_sanitizer = [
            'type'              => 'string',
            'sanitize_callback' => 'sanitize_text_field',
            'default'           => '',
        ];

        $url_sanitizer = [
            'type'              => 'string',
            'sanitize_callback' => 'esc_url_raw',
            'default'           => '',
        ];

        $special_character_sanitizer = [
            'type'              => 'string',
            'sanitize_callback' => 'esc_attr',
            'default'           => '',
        ];

        $boolean_sanitizer = [
            'type' => 'boolean',
            'sanitize_callback' => 'rest_sanitize_boolean',
            'default' => false
        ];

        register_setting('kartcommand_settings', 'kartcommand_enable_widget', $boolean_sanitizer);
        register_setting('kartcommand_settings', 'kartcommand_api_key', $text_field_sanitizer);
        register_setting('kartcommand_settings', 'kartcommand_domain', $text_field_sanitizer);
        register_setting('kartcommand_settings', 'kartcommand_chat_manager', $text_field_sanitizer);
        register_setting('kartcommand_settings', 'kartcommand_widget_color', $special_character_sanitizer);
        register_setting('kartcommand_settings', 'kartcommand_widget_banner_text', $text_field_sanitizer);
        register_setting('kartcommand_settings', 'kartcommand_widget_intro_message', $text_field_sanitizer);
        register_setting('kartcommand_settings', 'kartcommand_widget_logo_url', $url_sanitizer);


        add_settings_section(
            'kartcommand_general_section',
            'General Settings',
            array($this, 'general_section_callback'),
            'kartcommand'
        );
        
        add_settings_field(
            'kartcommand_enable_widget',
            'Enable Widget',
            array($this, 'enable_widget_callback'),
            'kartcommand',
            'kartcommand_general_section'
        );

        add_settings_field(
            'kartcommand_api_key',
            'API Key',
            array($this, 'api_key_callback'),
            'kartcommand',
            'kartcommand_general_section'
        );

        add_settings_field(
            'kartcommand_chat_manager',
            'Chat Manager ID',
            array($this, 'chat_manager_callback'),
            'kartcommand',
            'kartcommand_general_section'
        );

        add_settings_field(
            'kartcommand_widget_color',
            'Widget Color (RGB or HEX)',
            array($this, 'widget_color_callback'),
            'kartcommand',
            'kartcommand_general_section'
        );

        add_settings_field(
            'kartcommand_widget_banner_text',
            'Banner Text',
            array($this, 'widget_banner_text_callback'),
            'kartcommand',
            'kartcommand_general_section'
        );

        add_settings_field(
            'kartcommand_widget_intro_message',
            'Introduction Message',
            array($this, 'widget_intro_message_callback'),
            'kartcommand',
            'kartcommand_general_section'
        );

        add_settings_field(
            'kartcommand_domain',
            'Custom Domain (Optional)',
            array($this, 'domain_callback'),
            'kartcommand',
            'kartcommand_general_section'
        );

        add_settings_field(
            'kartcommand_widget_logo_url',
            'Widget Logo',
            array($this, 'widget_logo_url_callback'),
            'kartcommand',
            'kartcommand_general_section'
        );

    }

    public function general_section_callback()
    {
        echo '<p>Configure your KartCommand settings below:</p>';
    }

    public function api_key_callback()
    {
        $api_key = get_option('kartcommand_api_key');
        echo '<input type="password" id="kartcommand_api_key" name="kartcommand_api_key" value="' . esc_attr($api_key) . '" class="regular-text">';
        echo '<button type="button" class="button toggle-password" data-target="kartcommand_api_key"><span class="dashicons dashicons-visibility"></span></button>';
    }

    public function domain_callback()
    {
        $domain = get_option('kartcommand_domain');
        echo '<input type="text" id="kartcommand_domain" name="kartcommand_domain" placeholder="optional" value="' . esc_attr($domain) . '" class="regular-text">';
    }

    public function chat_manager_callback()
    {
        $chat_manager = get_option('kartcommand_chat_manager');
        echo '<input type="text" id="kartcommand_chat_manager" name="kartcommand_chat_manager" value="' . esc_attr($chat_manager) . '" class="regular-text">';
    }

    public function enable_widget_callback()
    {
        $enabled = get_option('kartcommand_enable_widget');
        echo '<input type="checkbox" id="kartcommand_enable_widget" name="kartcommand_enable_widget" value="1" ' . checked(1, $enabled, false) . '>';
    }

    public function widget_color_callback()
    {
        $widget_color = get_option('kartcommand_widget_color');
        echo '<input type="text" id="kartcommand_widget_color" name="kartcommand_widget_color" value="' . esc_attr($widget_color) . '" class="regular-text">';
    }

    public function widget_banner_text_callback()
    {
        $banner_text = get_option('kartcommand_widget_banner_text');
        echo '<input type="text" id="kartcommand_widget_banner_text" name="kartcommand_widget_banner_text" value="' . esc_attr($banner_text) . '" class="regular-text">';
    }

    public function widget_intro_message_callback()
    {
        $intro_message = get_option('kartcommand_widget_intro_message');
        echo '<input type="text" id="kartcommand_widget_intro_message" name="kartcommand_widget_intro_message" value="' . esc_attr($intro_message) . '" class="regular-text">';
    }

    public function widget_logo_url_callback()
    {
        $logo_url = get_option('kartcommand_widget_logo_url');
        ?>
        <input type="text" id="kartcommand_widget_logo_url" name="kartcommand_widget_logo_url" value="<?php echo esc_attr($logo_url); ?>" class="regular-text">
        <button type="button" class="button" id="upload_logo_button">Upload/Select Logo</button>
        <?php if ($logo_url): ?>
            <div style="margin-top: 10px;">
                <img src="<?php echo esc_url($logo_url); ?>" style="max-width: 300px; height: auto;" />
            </div>
        <?php endif; ?>

        <script>
        jQuery(document).ready(function ($) {
            $('#upload_logo_button').click(function (e) {
                e.preventDefault();
                var mediaUploader = wp.media({
                    title: 'Select or Upload Logo',
                    button: { text: 'Use this logo' },
                    multiple: false
                });

                mediaUploader.on('select', function () {
                    var attachment = mediaUploader.state().get('selection').first().toJSON();
                    $('#kartcommand_widget_logo_url').val(attachment.url);
                });

                mediaUploader.open();
            });
        });
        </script>
        <?php
    }

    public function display_admin_page()
    {
        // Add this before loading the admin template
        //error_log('KartCommand Settings:');
        //error_log('API Key: ' . (get_option('kartcommand_api_key') ? 'Set' : 'Not Set'));
        //error_log('Domain: ' . get_option('kartcommand_domain'));
        //error_log('Chat Manager ID: ' . get_option('kartcommand_chat_manager'));
        //error_log('Enable Widget: ' . get_option('kartcommand_enable_widget'));
        //error_log('Widget Color: ' . get_option('kartcommand_widget_color'));
        //error_log('Banner Text: ' . get_option('kartcommand_banner_text'));
        //error_log('Intro Message: ' . get_option('kartcommand_intro_message'));

        require_once plugin_dir_path(__FILE__) . '../templates/admin-settings.php';
    }

    public function send_settings_to_kartcommand($option_name, $old_value, $new_value)
    {
        // Identify the settings required for making the API request.
        $request_config = [
            'kartcommand_enable_widget',
            'kartcommand_api_key',
            'kartcommand_domain',
            'kartcommand_chat_manager',
        ];

        // Identify the settings to send in the payload.
        $payload_settings = [
            'kartcommand_widget_color',
            'kartcommand_widget_banner_text',
            'kartcommand_widget_intro_message',
            'kartcommand_widget_logo_url',
        ];

        // Collect request config values.
        $config = [];
        foreach ($request_config as $setting) {
            $config[$setting] = get_option($setting);
        }

        // Ensure required fields are present.
        if (empty($config['kartcommand_api_key']) || empty($config['kartcommand_domain'])) {
            //error_log('KartCommand API Error: Missing API key or domain.');
            return;
        }

        // Collect payload values.
        $payload = [];
        foreach ($payload_settings as $setting) {
            $key_without_prefix = str_replace('kartcommand_', '', $setting);
            $payload[$key_without_prefix] = get_option($setting);
        }

        // Send the settings to your system.
        $domain = !empty($config['kartcommand_domain']) ? $config['kartcommand_domain'] : 'app.kartcommand.com';

        $response = wp_remote_post('https://' . $domain . '/api/chat-manager/widget/' . $config['kartcommand_chat_manager'] . '/settings', [
            'method'    => 'POST',
            'body'      => json_encode($payload),
            'headers'   => [
                'Content-Type'  => 'application/json',
                'apiKey'        => $config['kartcommand_api_key'],
            ],
            'timeout'   => 15,
        ]);

        // Handle the response.
        if (is_wp_error($response)) {
            //error_log('KartCommand API Error: ' . $response->get_error_message());
            return;
        }

        $response_code = wp_remote_retrieve_response_code($response);
        if ($response_code !== 200) {
            //error_log('KartCommand API Error: Unexpected response code ' . $response_code);
        }
    }

}

new KartCommand_Admin();
