<?php

/**
 * KartCommand main class
 *
 * @package KartCommand
 * @since   1.0.0
 */

defined('ABSPATH') || exit;

/**
 * Main KartCommand Class.
 *
 * @class KartCommand
 */
final class KartCommand
{

    /**
     * Single instance of the KartCommand class
     *
     * @var KartCommand
     * @since 1.0.0
     */
    protected static $instance = null;

    /**
     * Main KartCommand Instance.
     *
     * Ensures only one instance of KartCommand is loaded or can be loaded.
     *
     * @since 1.0.0
     * @static
     * @return KartCommand - Main instance.
     */
    public static function instance()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    /**
     * KartCommand Constructor.
     */
    public function __construct()
    {
        $this->define_constants();
        $this->includes();
        $this->init_hooks();
    }

    /**
     * Define KartCommand Constants.
     */
    private function define_constants()
    {
        $this->define('KARTCOMMAND_ABSPATH', dirname(KARTCOMMAND_PLUGIN_DIR) . '/');
        $this->define('KARTCOMMAND_PLUGIN_BASENAME', plugin_basename(KARTCOMMAND_PLUGIN_DIR));
    }

    /**
     * Include required core files used in admin and on the frontend.
     */
    private function includes()
    {
        include_once KARTCOMMAND_PLUGIN_DIR . 'includes/class-kartcommand-manager.php';
        include_once KARTCOMMAND_PLUGIN_DIR . 'includes/class-kartcommand-admin.php';
        include_once KARTCOMMAND_PLUGIN_DIR . 'includes/class-kartcommand-public.php';
    }

    /**
     * Hook into actions and filters.
     */
    private function init_hooks()
    {
        add_action('plugins_loaded', array($this, 'on_plugins_loaded'), -1);
        add_action('init', array($this, 'init'), 0);
    }

    /**
     * Define constant if not already set.
     *
     * @param string      $name  Constant name.
     * @param string|bool $value Constant value.
     */
    private function define($name, $value)
    {
        if (!defined($name)) {
            define($name, $value);
        }
    }

    /**
     * Perform actions on plugins loaded.
     */
    public function on_plugins_loaded()
    {
        do_action('kartcommand_loaded');
    }

    /**
     * Init KartCommand when WordPress Initializes.
     */
    public function init()
    {
        // Before init action.
        do_action('before_kartcommand_init');

        // Set up localization.
        $this->load_plugin_textdomain();

        // Init action.
        do_action('kartcommand_init');
    }

    /**
     * Load Localization files.
     */
    private function load_plugin_textdomain()
    {
        load_plugin_textdomain('kartcommand', false, dirname(KARTCOMMAND_PLUGIN_BASENAME) . '/languages/');
    }
}
